==> ismah-3.0.2%2B1.21.5%2Bneoforge-sources.jar: com/github/razorplay01/ismah/common/mixin/PlayerRendererMixin.java <==
package com.github.razorplay01.ismah.common.mixin;

import com.github.razorplay01.ismah.client.util.LeashRenderer;
import com.github.razorplay01.ismah.client.util.LeashStateAccess;
import com.mojang.blaze3d.vertex.PoseStack;
import net.minecraft.client.Minecraft;
import net.minecraft.client.model.EntityModel;
import net.minecraft.client.model.PlayerModel;
import net.minecraft.client.player.AbstractClientPlayer;
import net.minecraft.client.renderer.MultiBufferSource;
import net.minecraft.client.renderer.entity.EntityRendererProvider;
import net.minecraft.client.renderer.entity.player.PlayerRenderer;
import net.minecraft.resources.ResourceLocation;
import net.minecraft.world.entity.HumanoidArm;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import com.github.razorplay01.ismah.client.util.RenderUtil;

@Mixin(PlayerRenderer.class)
public class PlayerRendererMixin {
    //? if forge {
    /*//? if >= 1.19 && <= 1.21.1 {
    @Inject(method = "renderRightHand", at = @At("TAIL"))
    public void renderRightHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, AbstractClientPlayer abstractClientPlayer, CallbackInfo ci) {
        if (((LeashStateAccess) abstractClientPlayer).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.RIGHT) {
            LeashRenderer.renderRightArmLeash(poseStack, buffer, combinedLight, (PlayerModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor((PlayerModel) ((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, abstractClientPlayer, HumanoidArm.RIGHT);
    }

    @Inject(method = "renderLeftHand", at = @At("TAIL"))
    public void renderLeftHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, AbstractClientPlayer abstractClientPlayer, CallbackInfo ci) {
        if (((LeashStateAccess) abstractClientPlayer).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.LEFT) {
            LeashRenderer.renderLeftArmLeash(poseStack, buffer, combinedLight, (PlayerModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor((PlayerModel) ((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, abstractClientPlayer, HumanoidArm.LEFT);
    }
    //?}
*///?}
//? if fabric {
    /*//? if >= 1.19 && <= 1.21.1 {
    /^@Inject(method = "renderRightHand", at = @At("TAIL"))
    public void renderRightHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, AbstractClientPlayer abstractClientPlayer, CallbackInfo ci) {
        if (((LeashStateAccess) abstractClientPlayer).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.RIGHT) {
            LeashRenderer.renderRightArmLeash(poseStack, buffer, combinedLight, (PlayerModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor((PlayerModel) ((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, abstractClientPlayer, HumanoidArm.RIGHT);
    }

    @Inject(method = "renderLeftHand", at = @At("TAIL"))
    public void renderLeftHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, AbstractClientPlayer abstractClientPlayer, CallbackInfo ci) {
        if (((LeashStateAccess) abstractClientPlayer).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.LEFT) {
            LeashRenderer.renderLeftArmLeash(poseStack, buffer, combinedLight, (PlayerModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor((PlayerModel) ((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, abstractClientPlayer, HumanoidArm.LEFT);
    }
    ^///?}

    //? if >= 1.21.2 {
    @Inject(method = "renderRightHand", at = @At("TAIL"))
    private void renderRightHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, net.minecraft.resources.ResourceLocation resourceLocation, boolean isSleeveVisible, CallbackInfo ci) {
        if (((LeashStateAccess) Minecraft.getInstance().player).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.RIGHT) {
            LeashRenderer.renderRightArmLeash(poseStack, buffer, combinedLight, (net.minecraft.client.model.HumanoidModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor(((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, HumanoidArm.RIGHT, isSleeveVisible);
    }

    @Inject(method = "renderLeftHand", at = @At("TAIL"))
    private void renderLeftHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, net.minecraft.resources.ResourceLocation resourceLocation, boolean isSleeveVisible, CallbackInfo ci) {
        if (((LeashStateAccess) Minecraft.getInstance().player).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.LEFT) {
            LeashRenderer.renderLeftArmLeash(poseStack, buffer, combinedLight, (net.minecraft.client.model.HumanoidModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor(((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, HumanoidArm.LEFT, isSleeveVisible);
    }
    //?}
*///?}
//? if neoforge {
    //? if 1.21 || 1.21.1 {
    /*@Inject(method = "renderRightHand", at = @At("TAIL"))
    private void renderRightHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, AbstractClientPlayer player, CallbackInfo ci) {
        if (((LeashStateAccess) player).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.RIGHT) {
            LeashRenderer.renderRightArmLeash(poseStack, buffer, combinedLight, (PlayerModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor((PlayerModel) ((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, player, HumanoidArm.RIGHT);
    }

    @Inject(method = "renderLeftHand", at = @At("TAIL"))
    private void renderLeftHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, AbstractClientPlayer player, CallbackInfo ci) {
        if (((LeashStateAccess) player).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.LEFT) {
            LeashRenderer.renderLeftArmLeash(poseStack, buffer, combinedLight, (PlayerModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor((PlayerModel) ((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, player, HumanoidArm.LEFT);
    }*///?}

    //? if >= 1.21.2 {
    @Inject(method = "renderRightHand(Lcom/mojang/blaze3d/vertex/PoseStack;Lnet/minecraft/client/renderer/MultiBufferSource;ILnet/minecraft/resources/ResourceLocation;ZLnet/minecraft/client/player/AbstractClientPlayer;)V", at = @At("TAIL"))
    private void renderRightHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, net.minecraft.resources.ResourceLocation arg3, boolean isSleeveVisible, AbstractClientPlayer player, CallbackInfo ci) {
        if (((LeashStateAccess) player).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.RIGHT) {
            LeashRenderer.renderRightArmLeash(poseStack, buffer, combinedLight, (net.minecraft.client.model.HumanoidModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor(((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, HumanoidArm.RIGHT, isSleeveVisible);
    }

    @Inject(method = "renderLeftHand(Lcom/mojang/blaze3d/vertex/PoseStack;Lnet/minecraft/client/renderer/MultiBufferSource;ILnet/minecraft/resources/ResourceLocation;ZLnet/minecraft/client/player/AbstractClientPlayer;)V", at = @At("TAIL"))
    private void renderLeftHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, net.minecraft.resources.ResourceLocation arg3, boolean isSleeveVisible, AbstractClientPlayer player, CallbackInfo ci) {
        if (((LeashStateAccess) player).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.LEFT) {
            LeashRenderer.renderLeftArmLeash(poseStack, buffer, combinedLight, (net.minecraft.client.model.HumanoidModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor(((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, HumanoidArm.LEFT, isSleeveVisible);
    }
    //?}
//?}
}

==> ismah-3.1.1%2B1.21%2Bneoforge-sources.jar: com/github/razorplay01/ismah/common/mixin/PlayerRendererMixin.java <==
package com.github.razorplay01.ismah.common.mixin;

import com.github.razorplay01.ismah.client.util.*;
import com.mojang.blaze3d.vertex.PoseStack;
import net.minecraft.client.Minecraft;
import net.minecraft.client.model.PlayerModel;
import net.minecraft.client.player.AbstractClientPlayer;
import net.minecraft.client.renderer.MultiBufferSource;
import net.minecraft.client.renderer.entity.EntityRendererProvider;
import net.minecraft.client.renderer.entity.player.PlayerRenderer;
import net.minecraft.world.entity.Entity;
import net.minecraft.world.entity.HumanoidArm;
import net.minecraft.world.entity.player.Player;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(PlayerRenderer.class)
public class PlayerRendererMixin {
    @Inject(method = "<init>", at = @At("RETURN"))
    public void init(EntityRendererProvider.Context context, boolean bl, CallbackInfo ci) {
        ((LivingEntityRendererAccessor) this).invokeAddFeature(new LeashRenderLayer<>((PlayerRenderer) (Object) this));
    }

    //? if >= 1.21.2 {
    /*@Inject(method = "extractRenderState(Lnet/minecraft/client/player/AbstractClientPlayer;Lnet/minecraft/client/renderer/entity/state/PlayerRenderState;F)V", at = @At("RETURN"))
    private void onExtractRenderState(AbstractClientPlayer abstractClientPlayer, net.minecraft.client.renderer.entity.state.PlayerRenderState playerRenderState, float f, CallbackInfo ci) {
        ((PlayerRenderStateAccessor) playerRenderState).setPlayer(abstractClientPlayer);
    }
    *///?}

    //? if forge {
    /*//? if >= 1.19 && <= 1.21.1 {
    @Inject(method = "renderRightHand", at = @At("TAIL"))
    public void renderRightHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, AbstractClientPlayer abstractClientPlayer, CallbackInfo ci) {
        if (((LeashStateAccess) abstractClientPlayer).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.RIGHT) {
            LeashRenderer.renderRightArmLeash(poseStack, buffer, combinedLight, (PlayerModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor((PlayerModel) ((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, abstractClientPlayer, HumanoidArm.RIGHT);
    }

    @Inject(method = "renderLeftHand", at = @At("TAIL"))
    public void renderLeftHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, AbstractClientPlayer abstractClientPlayer, CallbackInfo ci) {
        if (((LeashStateAccess) abstractClientPlayer).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.LEFT) {
            LeashRenderer.renderLeftArmLeash(poseStack, buffer, combinedLight, (PlayerModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor((PlayerModel) ((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, abstractClientPlayer, HumanoidArm.LEFT);
    }
    //?}
*///?}
//? if fabric {
    /*//? if >= 1.19 && <= 1.21.1 {
    @Inject(method = "renderRightHand", at = @At("TAIL"))
    public void renderRightHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, AbstractClientPlayer abstractClientPlayer, CallbackInfo ci) {
        if (((LeashStateAccess) abstractClientPlayer).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.RIGHT) {
            LeashRenderer.renderRightArmLeash(poseStack, buffer, combinedLight, (PlayerModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor((PlayerModel) ((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, abstractClientPlayer, HumanoidArm.RIGHT);
    }

    @Inject(method = "renderLeftHand", at = @At("TAIL"))
    public void renderLeftHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, AbstractClientPlayer abstractClientPlayer, CallbackInfo ci) {
        if (((LeashStateAccess) abstractClientPlayer).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.LEFT) {
            LeashRenderer.renderLeftArmLeash(poseStack, buffer, combinedLight, (PlayerModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor((PlayerModel) ((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, abstractClientPlayer, HumanoidArm.LEFT);
    }
    //?}

    //? if >= 1.21.2 {
    /^@Inject(method = "renderRightHand", at = @At("TAIL"))
    private void renderRightHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, net.minecraft.resources.ResourceLocation resourceLocation, boolean isSleeveVisible, CallbackInfo ci) {
        if (((LeashStateAccess) Minecraft.getInstance().player).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.RIGHT) {
            LeashRenderer.renderRightArmLeash(poseStack, buffer, combinedLight, (net.minecraft.client.model.HumanoidModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor(((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, HumanoidArm.RIGHT, isSleeveVisible);
    }

    @Inject(method = "renderLeftHand", at = @At("TAIL"))
    private void renderLeftHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, net.minecraft.resources.ResourceLocation resourceLocation, boolean isSleeveVisible, CallbackInfo ci) {
        if (((LeashStateAccess) Minecraft.getInstance().player).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.LEFT) {
            LeashRenderer.renderLeftArmLeash(poseStack, buffer, combinedLight, (net.minecraft.client.model.HumanoidModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor(((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, HumanoidArm.LEFT, isSleeveVisible);
    }
    ^///?}
*///?}
//? if neoforge {
    //? if 1.21 || 1.21.1 {
    @Inject(method = "renderRightHand", at = @At("TAIL"))
    private void renderRightHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, AbstractClientPlayer player, CallbackInfo ci) {
        if (((LeashStateAccess) player).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.RIGHT) {
            LeashRenderer.renderRightArmLeash(poseStack, buffer, combinedLight, (PlayerModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor((PlayerModel) ((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, player, HumanoidArm.RIGHT);
    }

    @Inject(method = "renderLeftHand", at = @At("TAIL"))
    private void renderLeftHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, AbstractClientPlayer player, CallbackInfo ci) {
        if (((LeashStateAccess) player).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.LEFT) {
            LeashRenderer.renderLeftArmLeash(poseStack, buffer, combinedLight, (PlayerModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor((PlayerModel) ((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, player, HumanoidArm.LEFT);
    }//?}

    //? if >= 1.21.2 {
    /*@Inject(method = "renderRightHand(Lcom/mojang/blaze3d/vertex/PoseStack;Lnet/minecraft/client/renderer/MultiBufferSource;ILnet/minecraft/resources/ResourceLocation;ZLnet/minecraft/client/player/AbstractClientPlayer;)V", at = @At("TAIL"))
    private void renderRightHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, net.minecraft.resources.ResourceLocation arg3, boolean isSleeveVisible, AbstractClientPlayer player, CallbackInfo ci) {
        if (((LeashStateAccess) player).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.RIGHT) {
            LeashRenderer.renderRightArmLeash(poseStack, buffer, combinedLight, (net.minecraft.client.model.HumanoidModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor(((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, HumanoidArm.RIGHT, isSleeveVisible);
    }

    @Inject(method = "renderLeftHand(Lcom/mojang/blaze3d/vertex/PoseStack;Lnet/minecraft/client/renderer/MultiBufferSource;ILnet/minecraft/resources/ResourceLocation;ZLnet/minecraft/client/player/AbstractClientPlayer;)V", at = @At("TAIL"))
    private void renderLeftHand(PoseStack poseStack, MultiBufferSource buffer, int combinedLight, net.minecraft.resources.ResourceLocation arg3, boolean isSleeveVisible, AbstractClientPlayer player, CallbackInfo ci) {
        if (((LeashStateAccess) player).getLeashState() && Minecraft.getInstance().options.mainHand().get() == HumanoidArm.LEFT) {
            LeashRenderer.renderLeftArmLeash(poseStack, buffer, combinedLight, (net.minecraft.client.model.HumanoidModel) ((LivingEntityRendererAccessor) this).getModel());
        }
        RenderUtil.renderArmor(((LivingEntityRendererAccessor) this).getModel(), poseStack, buffer, combinedLight, HumanoidArm.LEFT, isSleeveVisible);
    }
    *///?}
//?}
}
